@@ -1,6 +1,6 @@
 package Sloth;
 BEGIN {
-  $Sloth::VERSION = '0.02';
+  $Sloth::VERSION = '0.03';
 }
 # ABSTRACT: A PSGI compatible REST framework
 
@@ -84,11 +84,11 @@ has router => (
         my $self = shift;
         my $router = Path::Router->new;
         for my $resource ($self->resources) {
-            $router->add_route(
-                $resource->path => (
-                    target => $resource
+            for my $route (@{ $resource->_routes }) {
+                $router->include_router(
+                    $resource->path => $route
                 )
-            );
+            }
         }
         return $router;
     },
@@ -133,6 +133,13 @@ sub _request {
     }
 }
 
+sub prepare_app {
+    my $self = shift;
+
+    # Force creation of lazy attributes
+    $self->resources;
+    $self->representations;
+}
 
 1;
 
